/*
 * frames and directories for fast interval record access
 *
 * a frame directory of NUMBER_OF_FRAMES entries is followed by the frames
 */
#define MAX_NUM_OF_FRAMES 256
#define HEADER_VERSION 6
/*
 * version 6: restructure thread_entry data structure
              thread type 0=MPI, 1=user, 2=system, add cpuid for each thread 
 * version 5: 
 * version 4: enlarge thread_entry from 6 words to 8 words for thread type
 * version 3: add marker hash table for each thread
 * version 2: enlarge thread_entry from 4 words to 6 words and record_frame
 *            from 6 to 8 words (with both frame start time and record end time)
 *            frame directory also has previous directory offset
 * version 1: April 20, 1999
 */

/*
 * frame structure
 * interval records are added one at a time according to end_time, not start_time
 */
typedef struct _record_frame {
  fpos_t frame_offset;          /* frame starting offset, required field */
  double frame_stime;           /* frame start time, required field */
  double frame_etime;           /* frame end time, required field */
  int frame_size;               /* frame size in bytes, place holder */
  int num_of_records;           /* number of records in frame, place holder */
} record_frame;
  
/*
 * frame directory structure
 */
typedef struct _frame_directory {
  int directory_size;                /* directory size */
  int number_of_frames;              /* number of frames in directory */
  int number_of_records;             /* number of records in each frame */
  fpos_t offset;                     /* directory offset */
  fpos_t next_offset;                /* next directory offset */
  fpos_t prev_offset;                /* previous directory offset */
  record_frame frame[MAX_NUM_OF_FRAMES]; /* frames */
/*
 * current frame related info
 */
  int current_frame;                 /* current frame */
  fpos_t current_offset;             /* current offset */
  int current_size;                  /* current frame size */
  int current_count;                 /* current frame record count */
  double current_stime;              /* current frame start time */
  double current_etime;              /* current record end_time */
} frame_directory;


